package com.aliyun.vodplayer.demo.activity.advance;

import android.content.Context;
import android.graphics.SurfaceTexture;
import android.opengl.GLES20;
import android.os.Bundle;
import android.support.v7.widget.DividerItemDecoration;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.Surface;
import android.view.TextureView;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.alivc.player.VcPlayerLog;
import com.aliyun.vodplayer.demo.R;
import com.aliyun.vodplayer.demo.utils.BaseAppCompatActivity;
import com.aliyun.vodplayer.media.AliyunLocalSource;
import com.aliyun.vodplayer.media.AliyunVodPlayer;
import com.aliyun.vodplayer.media.IAliyunVodPlayer;

import java.util.ArrayList;

import javax.microedition.khronos.egl.EGL10;
import javax.microedition.khronos.egl.EGLConfig;
import javax.microedition.khronos.egl.EGLContext;
import javax.microedition.khronos.egl.EGLDisplay;
import javax.microedition.khronos.egl.EGLSurface;

import com.aliyun.vodplayer.demo.utils.OnClickListener;
/**
 *
 */

public class DemoMultiPlayerActivity extends BaseAppCompatActivity {

    public static final String URL = "http://livecdn.video.taobao.com/temp/test1466295255657-65e172e6-1b96-4660-9f2f-1aba576d84e8.m3u8";
    private static final String TAG = DemoMultiPlayerActivity.class.getSimpleName();

    private PlayerManager playerManager;
    private LinearLayoutManager layoutManager;
    private RecyclerView mRecycleView;
    private RecyclerAdapter adapter;

    private TextureView textureView;

    public static ArrayList<AliyunLocalSource> urlList = new ArrayList<AliyunLocalSource>();


    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        getWindow().setFlags(
                WindowManager.LayoutParams.FLAG_HARDWARE_ACCELERATED,
                WindowManager.LayoutParams.FLAG_HARDWARE_ACCELERATED);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);

        setContentView(R.layout.activity_multi_player);


        initUrlList();

        mRecycleView = (RecyclerView) findViewById(R.id.recycleView);
        //垂直滑动
        layoutManager = new LinearLayoutManager(this);
        layoutManager.setOrientation(LinearLayoutManager.VERTICAL);
        layoutManager.findFirstVisibleItemPosition();
        mRecycleView.setLayoutManager(layoutManager);

        mRecycleView.addItemDecoration(new DividerItemDecoration(this, DividerItemDecoration.HORIZONTAL));

        playerManager = new PlayerManager(getApplicationContext(), new AliyunVodPlayer(this));
        adapter = new RecyclerAdapter(playerManager, getLayoutInflater());

        mRecycleView.setAdapter(adapter);

        mRecycleView.addOnScrollListener(new RecyclerView.OnScrollListener() {
            @Override
            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                super.onScrolled(recyclerView, dx, dy);

                int currentPlayPosition = playerManager.getPosition();
                int firstVisiblePosition = layoutManager.findFirstVisibleItemPosition();
                int lastVisiblePosition = layoutManager.findLastVisibleItemPosition();

                Log.d(TAG, "currentPlayPosition = " + currentPlayPosition
                        + " ,  firstVisiblePosition = " + firstVisiblePosition
                        + " , lastVisiblePosition = " + lastVisiblePosition);

                if (currentPlayPosition == firstVisiblePosition - 1) {
                    //可能需要stop。
                    playerManager.stop();
                } else {
                    //相等的话，不许要操作
                }

                if (currentPlayPosition == lastVisiblePosition + 1) {
                    //需要stop。
                    playerManager.stop();
                } else {
                    //相等的话，不许要操作
                }

            }
        });


    }

    @Override
    public void onResume() {
        super.onResume();

        int playingPosition = playerManager.getPosition();
        if (playingPosition >= 0) {
            //说明有在播放的
            playerManager.resetTextureView();
        }
    }

    private void initUrlList() {
        AliyunLocalSource.AliyunLocalSourceBuilder asb = new AliyunLocalSource.AliyunLocalSourceBuilder();
        asb.setSource("http://player.alicdn.com/video/aliyunmedia.mp4");
        asb.setTitle("阿里视频云介绍");
        urlList.add(asb.build());

        asb.setSource("http://livetest.aliyunlive.com/9725750fa11648eba3426f65920ccecd/bce6da0b4afd43bb9fd06af269816b82-4b6ffae84f2e1d243955ecaedcf11a3e.m3u8");
        asb.setTitle("奥运会");
        urlList.add(asb.build());

        asb.setSource("http://livetest.aliyunlive.com/af6b16749fb44f2cb26c7c9b7cf3e3b2/3d8d93f8791c4e019388fd57e7dc9efb-4b6ffae84f2e1d243955ecaedcf11a3e.m3u8");
        asb.setTitle("多媒体");
        urlList.add(asb.build());

        asb.setSource("http://saas-video-qp.qupaicloud.com/299B3F9B-15BE76DF272-1767-9096-266-17559/8b8c03c80c2f43bf903a76621a6008d8.m3u8");
        asb.setTitle("MV素材演示");
        urlList.add(asb.build());

        asb.setSource("http://saas-video-qp.qupaicloud.com/4b5561fcda2d4825b2285a48e3b25389/1071bc468d85488bb98eef1867a98fca-699a80a29a15c59c9d0868389f86cc3f.mp4");
        asb.setTitle("MV效果演示");
        urlList.add(asb.build());
    }


    private static class RecyclerAdapter extends RecyclerView.Adapter {

        private static final String TAG = RecyclerAdapter.class.getSimpleName();
        private LayoutInflater mLayoutInflater;
        private PlayerManager mPlayerManager;


        public RecyclerAdapter(PlayerManager playerManager, LayoutInflater layoutInflater) {
            mPlayerManager = playerManager;
            mLayoutInflater = layoutInflater;
        }

        @Override
        public RecyclerView.ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
            View itemView = mLayoutInflater.inflate(R.layout.view_multi_item, parent, false);
            MyHolder holder = new MyHolder(itemView, mPlayerManager);
            return holder;
        }

        @Override
        public void onBindViewHolder(RecyclerView.ViewHolder holder, int position) {
            VcPlayerLog.d(TAG, " onBindViewHolder " + position);

            AliyunLocalSource localSource = urlList.get(position % 5);
            ((MyHolder) holder).setTag(position);
            ((MyHolder) holder).bindData(localSource);
        }

        @Override
        public int getItemCount() {

            return 100;
        }

    }

    private static class MyHolder extends RecyclerView.ViewHolder {

        private RelativeLayout playView;
        private TextView titleView;
        private int position;
        private PlayerManager playerManager;

        public MyHolder(final View itemView, PlayerManager manager) {
            super(itemView);

            playerManager = manager;

            playView = (RelativeLayout) itemView.findViewById(R.id.playView);

            titleView = (TextView) itemView.findViewById(R.id.titleview);
            playView.setOnClickListener(new OnClickListener() {
                @Override
                public void onClick(View v) {

                    playView.setVisibility(View.INVISIBLE);
                    TextureView textureView = new TextureView(itemView.getContext());
                    textureView.setSurfaceTextureListener(new TextureView.SurfaceTextureListener() {
                        @Override
                        public void onSurfaceTextureAvailable(SurfaceTexture surface, int width, int height) {
                            Log.d(DemoMultiPlayerActivity.TAG, " onSurfaceTextureAvailable ");
                            playerManager.start(MyHolder.this);
                            playerManager.setSurfaceTexture(surface);
                        }

                        @Override
                        public void onSurfaceTextureSizeChanged(SurfaceTexture surface, int width, int height) {

                        }

                        @Override
                        public boolean onSurfaceTextureDestroyed(SurfaceTexture surface) {
                            Log.d(DemoMultiPlayerActivity.TAG, " onSurfaceTextureDestroyed ");
                            return true;
                        }

                        @Override
                        public void onSurfaceTextureUpdated(SurfaceTexture surface) {

                        }
                    });

                    addTextureView(textureView);

                }


            });

        }

        public void bindData(AliyunLocalSource localSource) {
            titleView.setText(localSource.getTitle() + position);
        }

        public void setTag(int position) {
            this.position = position;

            if (playerManager.getPosition() == position) {
                //是当前播放的item
                playView.setVisibility(View.INVISIBLE);
            } else {
                viewStopped();
            }
        }

        private void viewStopped() {
            removeTextureView();
            playView.setVisibility(View.VISIBLE);
        }

        private void addTextureView(TextureView textureView) {
            RelativeLayout.LayoutParams param = new RelativeLayout.LayoutParams(RelativeLayout.LayoutParams.MATCH_PARENT,
                    RelativeLayout.LayoutParams.MATCH_PARENT);
            ((RelativeLayout) MyHolder.this.itemView).addView(textureView, 0, param);
        }

        public void removeTextureView() {
            View firstChildView = ((RelativeLayout) MyHolder.this.itemView).getChildAt(0);
            if (firstChildView instanceof TextureView) {
                Log.d(TAG, "remove at 0 ");
                ((RelativeLayout) MyHolder.this.itemView).removeView(firstChildView);
            }
        }

        public int getTag() {
            return position;
        }

        public void stop() {
            Log.d(TAG, "holder stop pos = " + position);
            viewStopped();
        }
    }


    private static class PlayerManager {

        private Context context;
        private AliyunVodPlayer vodPlayer;
        private int position = -1;


        private SurfaceTexture surfaceTexture;
        private MyHolder holder;

        public PlayerManager(final Context context, AliyunVodPlayer player) {
            this.context = context;
            vodPlayer = player;
            vodPlayer.enableNativeLog();
            vodPlayer.setCirclePlay(true);
            vodPlayer.setAutoPlay(true);
            vodPlayer.setReferer("http://aliyun.com");
            vodPlayer.setOnErrorListener(new IAliyunVodPlayer.OnErrorListener() {
                @Override
                public void onError(int arg0, int arg1, String msg) {
                    Toast.makeText(context.getApplicationContext(), msg, Toast.LENGTH_SHORT).show();
                    stop();
                }
            });
        }

        public void start(MyHolder holder) {
            if (holder.getTag() == this.position) {
                return;
            }

            stop();

            this.holder = holder;
            this.position = holder.getTag();

            Log.d(TAG, " start pos = " + position);
            AliyunLocalSource localSource = urlList.get(position % 5);


            vodPlayer.reset();

            Log.d(TAG, " prepareAsync pos = " + position);
            vodPlayer.prepareAsync(localSource);
        }

        public void resetTextureView() {
            if (holder != null) {
                holder.removeTextureView();

                TextureView textureView = new TextureView(context);
                textureView.setSurfaceTextureListener(new TextureView.SurfaceTextureListener() {
                    @Override
                    public void onSurfaceTextureAvailable(SurfaceTexture surface, int width, int height) {
                        Log.d(DemoMultiPlayerActivity.TAG, " onSurfaceTextureAvailable ");
                        setSurfaceTexture(surface);
                    }

                    @Override
                    public void onSurfaceTextureSizeChanged(SurfaceTexture surface, int width, int height) {

                    }

                    @Override
                    public boolean onSurfaceTextureDestroyed(SurfaceTexture surface) {
                        Log.d(DemoMultiPlayerActivity.TAG, " onSurfaceTextureDestroyed ");
                        return true;
                    }

                    @Override
                    public void onSurfaceTextureUpdated(SurfaceTexture surface) {

                    }
                });

                holder.addTextureView(textureView);
            }

        }

        public void setSurfaceTexture(SurfaceTexture surfaceTexture) {
            this.surfaceTexture = surfaceTexture;
            Surface surface = new Surface(surfaceTexture);
            vodPlayer.setSurface(surface);
        }

        public void stop() {

            Log.d(TAG, " stop pos = " + position);
            if (position < 0) {
                return;
            }
            this.position = -1;
            vodPlayer.stop();

            if (holder != null) {
//                clearSurface(surfaceTexture);
                holder.stop();
            }
        }

        public int getPosition() {
            return position;
        }

        public void release() {
            stop();
            vodPlayer.release();
        }

    }

    @Override
    protected void onDestroy() {
        playerManager.release();
        super.onDestroy();
    }


    /**
     * Clear the given surface Texture by attaching a GL context and clearing the surface.
     *
     * @param texture a valid SurfaceTexture
     */
    private static void clearSurface(SurfaceTexture texture) {
        if (texture == null) {
            return;
        }

        EGL10 egl = (EGL10) EGLContext.getEGL();
        EGLDisplay display = egl.eglGetDisplay(EGL10.EGL_DEFAULT_DISPLAY);
        egl.eglInitialize(display, null);

        int[] attribList = {
                EGL10.EGL_RED_SIZE, 8,
                EGL10.EGL_GREEN_SIZE, 8,
                EGL10.EGL_BLUE_SIZE, 8,
                EGL10.EGL_ALPHA_SIZE, 8,
                EGL10.EGL_RENDERABLE_TYPE, EGL10.EGL_WINDOW_BIT,
                EGL10.EGL_NONE, 0,      // placeholder for recordable [@-3]
                EGL10.EGL_NONE
        };
        EGLConfig[] configs = new EGLConfig[1];
        int[] numConfigs = new int[1];
        egl.eglChooseConfig(display, attribList, configs, configs.length, numConfigs);
        EGLConfig config = configs[0];
        EGLContext context = egl.eglCreateContext(display, config, EGL10.EGL_NO_CONTEXT, new int[]{
                12440, 2,
                EGL10.EGL_NONE
        });
        EGLSurface eglSurface = egl.eglCreateWindowSurface(display, config, texture,
                new int[]{
                        EGL10.EGL_NONE
                });

        egl.eglMakeCurrent(display, eglSurface, eglSurface, context);
        GLES20.glClearColor(0, 0, 0, 1);
        GLES20.glClear(GLES20.GL_COLOR_BUFFER_BIT);
        egl.eglSwapBuffers(display, eglSurface);
        egl.eglDestroySurface(display, eglSurface);
        egl.eglMakeCurrent(display, EGL10.EGL_NO_SURFACE, EGL10.EGL_NO_SURFACE,
                EGL10.EGL_NO_CONTEXT);
        egl.eglDestroyContext(display, context);
        egl.eglTerminate(display);
    }
}
