package com.aliyun.vodplayer.demo.activity.advance.download;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.ProgressBar;
import android.widget.TextView;
import android.widget.Toast;

import com.alivc.player.AliyunErrorCode;
import com.alivc.player.VcPlayerLog;
import com.aliyun.vodplayer.demo.R;
import com.aliyun.vodplayer.demo.activity.advance.SkinActivity;
import com.aliyun.vodplayer.downloader.AliyunDownloadManager;
import com.aliyun.vodplayer.downloader.AliyunDownloadMediaInfo;
import com.squareup.picasso.Picasso;

import java.util.ArrayList;
import java.util.List;

import com.aliyun.vodplayer.demo.utils.OnClickListener;
/**
 *
 */

public class DownloadAdapter extends BaseAdapter {

    private static final String TAG = DownloadAdapter.class.getSimpleName();
    private final AliyunDownloadManager downloadManager;
    private Context mContext;

    public DownloadAdapter(Context context) {
        mContext = context.getApplicationContext();

        downloadManager = AliyunDownloadManager.getInstance(mContext.getApplicationContext());
    }

    public void addNewInfo(AliyunDownloadMediaInfo info) {
        if (!hasAdded(info)) {
            downloadItems.add(info);

            notifyDataSetChanged();
        }
    }

    public void addAllInfos(final List<AliyunDownloadMediaInfo> downloadingMedias) {
        for (AliyunDownloadMediaInfo downloadMediaInfo : downloadingMedias) {
            if (!hasAdded(downloadMediaInfo)) {
                downloadItems.add(downloadMediaInfo);

            }
        }
        notifyDataSetChanged();
    }


    private boolean hasAdded(AliyunDownloadMediaInfo info) {
        for (AliyunDownloadMediaInfo downloadMediaInfo : downloadItems) {
            if (info.getFormat().equals(downloadMediaInfo.getFormat()) &&
                    info.getQuality().equals(downloadMediaInfo.getQuality()) &&
                    info.getVid().equals(downloadMediaInfo.getVid()) &&
                    info.isEncripted() == downloadMediaInfo.isEncripted()) {
                return true;
            }
        }
        return false;
    }

    private List<AliyunDownloadMediaInfo> downloadItems = new ArrayList<AliyunDownloadMediaInfo>();

    @Override
    public int getCount() {
        return downloadItems.size();
    }

    @Override
    public Object getItem(int position) {
        return downloadItems.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        DownloadItemHolder holder = null;
        if (convertView == null) {
            convertView = LayoutInflater.from(mContext.getApplicationContext()).inflate(R.layout.adapter_item_download, null);
            holder = new DownloadItemHolder(convertView);
            convertView.setTag(holder);
        } else {
            holder = (DownloadItemHolder) convertView.getTag();
        }

        AliyunDownloadMediaInfo info = downloadItems.get(position);
        holder.bindData(info);

        //设置id，供自动化测试用
        int id = R.id.custom_id_min + position;
        convertView.setId(id);

        return convertView;
    }

    public List<AliyunDownloadMediaInfo> getDownloadMedias() {
        return downloadItems;
    }


    private class DownloadItemHolder {
        private ImageView cover;
        private TextView title, status;
        private ProgressBar progressBar;
        private Button start, stop, remove, play;

        public DownloadItemHolder(View convertView) {
            cover = (ImageView) convertView.findViewById(R.id.cover);
            title = (TextView) convertView.findViewById(R.id.title);
            status = (TextView) convertView.findViewById(R.id.status);
            progressBar = (ProgressBar) convertView.findViewById(R.id.progressbar);
            start = (Button) convertView.findViewById(R.id.start);
            stop = (Button) convertView.findViewById(R.id.stop);
            remove = (Button) convertView.findViewById(R.id.remove);
            play = (Button) convertView.findViewById(R.id.play);
        }


        public void bindData(final AliyunDownloadMediaInfo info) {
            String coverUrl = info.getCoverUrl();
            if(!TextUtils.isEmpty(coverUrl)) {
                Picasso.with(mContext).load(coverUrl).into(cover);
            }else{
                Picasso.with(mContext).load(R.drawable.default_cover).into(cover);
            }
            if (info.isEncripted() == 1) {
                title.setText(info.getTitle() + "(" + info.getFormat() + "," + info.getQuality() + "," + info.getSizeStr() + ",加密" + ")");
            } else {
                title.setText(info.getTitle() + "(" + info.getFormat() + "," + info.getQuality() + "," + info.getSizeStr() + ")");
            }
            VcPlayerLog.d(TAG, "progress = " + info.getProgress());
            progressBar.setProgress(info.getProgress());
            status.setText(info.getStatus().toString());
            start.setOnClickListener(new OnClickListener() {
                @Override
                public void onClick(View v) {

                    if(info.getStatus() == AliyunDownloadMediaInfo.Status.Complete){
                        Toast.makeText(mContext.getApplicationContext(), R.string.download_has_compeleted, Toast.LENGTH_LONG).show();
                        return;
                    }

                    downloadManager.startDownloadMedia(info);
                }
            });
            stop.setOnClickListener(new OnClickListener() {
                @Override
                public void onClick(View v) {
                    downloadManager.stopDownloadMedia(info);
                }
            });
            remove.setOnClickListener(new OnClickListener() {
                @Override
                public void onClick(View v) {
                    downloadManager.removeDownloadMedia(info);
                    downloadItems.remove(info);
                    notifyDataSetChanged();
                }
            });
            play.setOnClickListener(new OnClickListener() {
                @Override
                public void onClick(View v) {


                    if(info.getStatus() != AliyunDownloadMediaInfo.Status.Complete){
                        Toast.makeText(mContext.getApplicationContext(), R.string.download_has_not_compeleted, Toast.LENGTH_LONG).show();
                        return;
                    }



                    Intent intent = new Intent();
                    if (!(mContext instanceof Activity)) {
                        intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                    }
                    intent.setClass(mContext, SkinActivity.class);
                    intent.putExtra("type", "localSource");
                    intent.putExtra("url", info.getSavePath());
                    mContext.startActivity(intent);
                }
            });

        }
    }

    public void updateInfo(AliyunDownloadMediaInfo aliyunDownloadMediaInfo) {
        AliyunDownloadMediaInfo tmpInfo = null;
        for (AliyunDownloadMediaInfo info : downloadItems) {
            if (info.getVid().equals(aliyunDownloadMediaInfo.getVid()) &&
                    info.getQuality().equals(aliyunDownloadMediaInfo.getQuality()) &&
                    info.getFormat().equals(aliyunDownloadMediaInfo.getFormat())) {
                tmpInfo = info;
                break;
            }
        }

        if (tmpInfo != null) {
            tmpInfo.setSavePath(aliyunDownloadMediaInfo.getSavePath());
            tmpInfo.setProgress(aliyunDownloadMediaInfo.getProgress());
            tmpInfo.setStatus(aliyunDownloadMediaInfo.getStatus());
        }
    }
}
