package com.aliyun.vodplayer.demo.activity.advance.liveanswer;

import android.content.Context;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.aliyun.vodplayer.demo.R;
import com.aliyun.vodplayer.demo.activity.advance.liveanswer.bean.OptionInfo;
import com.aliyun.vodplayer.demo.activity.advance.liveanswer.bean.QuestionInfo;


/*
 * Copyright (C) 2010-2017 Alibaba Group Holding Limited.
 */
public class AnswerItemView extends RelativeLayout {

    private AnswerProgressBar mIndicator;
    private TextView mAnswerMsg;
    private TextView mAnswerNum;

    private OptionInfo mAnswerInfo;

    public AnswerItemView(Context context) {
        super(context);
        init();
    }

    public AnswerItemView(Context context, AttributeSet attrs) {
        super(context, attrs);
        init();
    }

    public AnswerItemView(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        init();
    }

    private void init() {
        LayoutInflater.from(getContext()).inflate(R.layout.view_answer_item, this, true);

        mIndicator = (AnswerProgressBar) findViewById(R.id.answer_indcator);
        mAnswerMsg = (TextView) findViewById(R.id.answer_msg);
        mAnswerNum = (TextView) findViewById(R.id.answer_num);

    }

    public void setAnswer(OptionInfo answer) {
        mChooseThis = false;
        mAnswerInfo = answer;
        mIndicator.setMax(1);
        mIndicator.setProgress(0);
        mAnswerMsg.setText(answer.answerDesc);
        mIndicator.setType(AnswerProgressBar.Type.Yellow);
    }

    private boolean mChooseThis = false;

    public void chooseThis() {
        mChooseThis = true;
        mIndicator.setMax(1);
        mIndicator.setProgress(1);
        mIndicator.setType(AnswerProgressBar.Type.Yellow);
    }

    public void showResult(QuestionInfo questionReportInfo) {
        if (questionReportInfo == null) {
            return;
        }
        OptionInfo[] optionInfos = questionReportInfo.options;
        if (optionInfos == null) {
            return;
        }


        OptionInfo reportOption = null;
        for (OptionInfo ans : optionInfos) {


            if (ans.answerId.equals(mAnswerInfo.answerId)) {
                reportOption = ans;
            }
        }

        showResult(questionReportInfo.totalUserNumber, reportOption.userNumber, reportOption.isCorrect, mChooseThis);
    }

    private void showResult(int totalNum, int chooseNum, boolean isRight, boolean isMyChoose) {

        mAnswerNum.setText(chooseNum + "人");

        if (totalNum == 0) {
            totalNum = 1;
        }

        mIndicator.setMax(totalNum);
        mIndicator.setProgress(chooseNum == 0 ? totalNum : chooseNum);
        if (isRight) {
            mIndicator.setType(AnswerProgressBar.Type.Yellow);
        } else {
            mIndicator.setType(AnswerProgressBar.Type.Gray);
        }

    }

    public OptionInfo getAnswer() {
        return mAnswerInfo;
    }


}
