package com.aliyun.vodplayer.demo.activity.advance.liveanswer;

import android.animation.Animator;
import android.animation.ValueAnimator;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.RectF;
import android.support.annotation.Nullable;
import android.util.AttributeSet;
import android.view.View;
import android.view.animation.LinearInterpolator;

import com.aliyun.vodplayer.demo.R;

import java.lang.ref.WeakReference;


/*
 * Copyright (C) 2010-2017 Alibaba Group Holding Limited.
 */
public class CircleBar extends View {

    ValueAnimator angleAnim = null;
    float mAngle = 0;
    float strokeWidth;

    private Paint arcPaint;
    private Paint solidPaint;

    public CircleBar(Context context) {
        super(context);
        init();
    }

    public CircleBar(Context context, @Nullable AttributeSet attrs) {
        super(context, attrs);
        init();
    }


    public CircleBar(Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        init();
    }

    private void init() {
        strokeWidth = getResources().getDimension(R.dimen.circle_stroke_width);

        arcPaint = new Paint();
        arcPaint.setAntiAlias(true);
        arcPaint.setColor(Contants.COLOR_YELLOW);
        arcPaint.setStrokeWidth(strokeWidth);
        arcPaint.setStyle(Paint.Style.STROKE);


        solidPaint = new Paint();
        solidPaint.setAntiAlias(true);
        solidPaint.setStrokeWidth(strokeWidth);
        solidPaint.setStyle(Paint.Style.FILL);
    }

    public void setDuration(int durationMs) {
        angleAnim = ValueAnimator.ofFloat(0, 360);
        angleAnim.setDuration(durationMs);
        angleAnim.setInterpolator(new LinearInterpolator());
        angleAnim.addUpdateListener(new MyAnimUpdateListener(this));
        angleAnim.addListener(new Animator.AnimatorListener() {
            @Override
            public void onAnimationStart(Animator animation) {

            }

            @Override
            public void onAnimationEnd(Animator animation) {
                if (onAngleChangeListener != null) {
                    onAngleChangeListener.onAngleEnd();
                }
            }

            @Override
            public void onAnimationCancel(Animator animation) {

            }

            @Override
            public void onAnimationRepeat(Animator animation) {

            }
        });
    }

    private void updateAngle(float angle) {
        mAngle = angle;
        postInvalidate();
        if (onAngleChangeListener != null) {
            onAngleChangeListener.onAngleChanged(mAngle);
        }
    }


    private static class MyAnimUpdateListener implements ValueAnimator.AnimatorUpdateListener{

        private WeakReference<CircleBar> circleBarWeakReference;

        private MyAnimUpdateListener(CircleBar circleBar){
            circleBarWeakReference = new WeakReference<CircleBar>(circleBar);
        }

        @Override
        public void onAnimationUpdate(ValueAnimator valueAnimator) {
            float angle = (float) valueAnimator.getAnimatedValue();
            CircleBar circleBar = circleBarWeakReference.get();
            if(circleBar != null){
                circleBar.updateAngle(angle);
            }
        }
    }

    public void start() {
        mSolidColor = Contants.COLOR_WHITE;
        angleAnim.start();
    }

    private RectF rectf = null;

    @Override
    protected void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        if (rectf == null && getWidth() > 0) {
            rectf = new RectF(getPaddingLeft() + strokeWidth,
                    getPaddingTop() + strokeWidth,
                    getWidth() - getPaddingRight() - strokeWidth,
                    getHeight() - getPaddingBottom() - strokeWidth);
        }
        if (rectf != null) {
            canvas.rotate(-90, getWidth() / 2, getHeight() / 2);
            solidPaint.setColor(mSolidColor);
            canvas.drawArc(rectf, 0, 360, false, solidPaint);//绘制中间颜色
            canvas.drawArc(rectf, 0, mAngle, false, arcPaint);//绘制圆弧颜色
            canvas.rotate(90, getWidth() / 2, getHeight() / 2);
        }
    }

    private OnAngleChangeListener onAngleChangeListener;

    public void setOnAngleChangeListener(OnAngleChangeListener l) {
        onAngleChangeListener = l;
    }

    private int mSolidColor = Contants.COLOR_WHITE;


    public void showCircle(int solidColor) {
        mAngle = 360;
        mSolidColor = solidColor;
        postInvalidate();
    }

    public static interface OnAngleChangeListener {
        void onAngleChanged(float angle);

        void onAngleEnd();
    }
}
