package com.aliyun.vodplayer.demo.activity.advance.liveanswer;

import android.content.Context;
import android.graphics.Color;
import android.util.AttributeSet;
import android.util.TypedValue;
import android.view.LayoutInflater;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.aliyun.vodplayer.demo.R;


/*
 * Copyright (C) 2010-2017 Alibaba Group Holding Limited.
 */
public class DecountTitleView extends RelativeLayout {

    private static int HANZI_SP = 18;
    private static int SHUZI_SP = 24;

    private CircleBar mCircleBar;
    private TextView mCountText;

    public DecountTitleView(Context context) {
        super(context);
        init();
    }

    public DecountTitleView(Context context, AttributeSet attrs) {
        super(context, attrs);
        init();
    }

    public DecountTitleView(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        init();
    }

    private void init() {
        LayoutInflater.from(getContext()).inflate(R.layout.view_decount_title, this, true);

        mCircleBar = (CircleBar) findViewById(R.id.circle_bar);
        mCountText = (TextView) findViewById(R.id.count_txt);

        mCircleBar.setOnAngleChangeListener(new CircleBar.OnAngleChangeListener() {
            @Override
            public void onAngleChanged(float angle) {
                int nowSecond = (int) (angle / anglePerSec);
                int leftSeconds = totalSecond - nowSecond;
                if (questionMode == TextMode.Lose) {
                    mCountText.setText("观战");
                    mCountText.setTextSize(TypedValue.COMPLEX_UNIT_SP, HANZI_SP);
                    mCountText.setBackgroundColor(Color.TRANSPARENT);
                    mCountText.setTextColor(Contants.COLOR_YELLOW);
                } else {
                    if (leftSeconds <= 3) {
                        mCountText.setText("" + leftSeconds);
                        mCountText.setTextSize(TypedValue.COMPLEX_UNIT_SP, SHUZI_SP);
                        mCountText.setBackgroundColor(Color.TRANSPARENT);
                        mCountText.setTextColor(Contants.COLOR_RED);
                    } else {
                        mCountText.setText("");
                        mCountText.setTextSize(TypedValue.COMPLEX_UNIT_SP, SHUZI_SP);
                        mCountText.setBackgroundResource(R.drawable.clock);
                        mCountText.setTextColor(Contants.COLOR_YELLOW);
                    }
                }

                if (onDecountListener != null) {
                    onDecountListener.onDecount(leftSeconds);
                }
            }

            @Override
            public void onAngleEnd() {
                if (onDecountListener != null) {
                    onDecountListener.onDecountEnd();
                }
            }
        });

    }

    private int totalSecond = 0;
    private float anglePerSec = 0;

    public void setDuration(int durationMs) {
        totalSecond = durationMs / 1000;
        anglePerSec = (360.0f * 1000 / durationMs);
        mCircleBar.setDuration(durationMs);
    }

    public void start() {
        mCountText.setText("");
        mCountText.setBackgroundResource(R.drawable.clock);
        mCircleBar.start();
    }

    private OnDecountListener onDecountListener;

    public void setOnDecountListener(OnDecountListener l) {
        onDecountListener = l;
    }

    public interface OnDecountListener {
        void onDecount(int value);

        void onDecountEnd();
    }

    public enum TextMode {
        Normal, Right, Wrong, Lose
    }

    private TextMode resultMode;
    private TextMode questionMode;

    public void setResultMode(TextMode mode) {
        resultMode = mode;
        if (TextMode.Right == mode) {
            mCountText.setText(R.string.live_answer_right);
            mCountText.setTextSize(TypedValue.COMPLEX_UNIT_SP, HANZI_SP);
            mCountText.setBackgroundColor(Color.TRANSPARENT);

            mCircleBar.showCircle(Contants.COLOR_YELLOW);
            mCountText.setTextColor(Contants.COLOR_WHITE);
        } else if (TextMode.Wrong == mode) {
            mCountText.setText(R.string.live_answer_wrong);
            mCountText.setTextSize(TypedValue.COMPLEX_UNIT_SP, HANZI_SP);
            mCountText.setBackgroundColor(Color.TRANSPARENT);

            mCircleBar.showCircle(Contants.COLOR_RED);
            mCountText.setTextColor(Contants.COLOR_WHITE);
        } else if (TextMode.Lose == mode) {
            mCountText.setText(R.string.live_answer_watch);
            mCountText.setTextSize(TypedValue.COMPLEX_UNIT_SP, HANZI_SP);
            mCountText.setBackgroundColor(Color.TRANSPARENT);

            mCircleBar.showCircle(Contants.COLOR_GRAY);
            mCountText.setTextColor(Contants.COLOR_WHITE);
        }
    }

    public void setQuestionMode(TextMode mode) {
        questionMode = mode;
        if (TextMode.Lose == mode) {
            mCountText.setText(R.string.live_answer_watch);
            mCountText.setTextSize(TypedValue.COMPLEX_UNIT_SP, HANZI_SP);
            mCountText.setBackgroundColor(Color.TRANSPARENT);
            mCountText.setTextColor(Contants.COLOR_YELLOW);
        } else {
            mCountText.setText("");
            mCountText.setTextSize(TypedValue.COMPLEX_UNIT_SP, SHUZI_SP);
            mCountText.setBackgroundResource(R.drawable.clock);
            mCountText.setTextColor(Contants.COLOR_YELLOW);
        }
    }


}
