package com.aliyun.vodplayer.demo.activity.advance.liveanswer;

import android.content.Context;
import android.graphics.Color;
import android.os.Handler;
import android.os.Message;
import android.support.annotation.Nullable;
import android.util.AttributeSet;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.LinearLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;


import com.aliyun.vodplayer.demo.R;
import com.aliyun.vodplayer.demo.activity.advance.liveanswer.bean.AnswerRequestInfo;
import com.aliyun.vodplayer.demo.activity.advance.liveanswer.bean.OptionInfo;
import com.aliyun.vodplayer.demo.activity.advance.liveanswer.bean.QuestionInfo;

import java.lang.ref.WeakReference;

/*
 * Copyright (C) 2010-2017 Alibaba Group Holding Limited.
 */
public class LiveAnswerView extends RelativeLayout {

    private Animation popInAnim;
    private Animation popOutAnim;

    private DecountTitleView decountTitleView;
    private TextView mQuestionView;
    private LinearLayout mAnswerList;

    private QuestionInfo mQuestionInfo = null;
    private OptionInfo mMyAnswer = null;

    private boolean mCanAnswer = true;

    private DecountTimer decountTimer;

    public LiveAnswerView(Context context) {
        super(context);
        init();
    }


    public LiveAnswerView(Context context, @Nullable AttributeSet attrs) {
        super(context, attrs);
        init();
    }


    public LiveAnswerView(Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        init();
    }

    private void init() {

        decountTimer = new DecountTimer(this);
        popInAnim = AnimationUtils.loadAnimation(getContext().getApplicationContext(), R.anim.pop_in);

        popOutAnim = AnimationUtils.loadAnimation(getContext().getApplicationContext(), R.anim.pop_out);
        popOutAnim.setAnimationListener(new Animation.AnimationListener() {
            @Override
            public void onAnimationStart(Animation animation) {

            }

            @Override
            public void onAnimationEnd(Animation animation) {
                setVisibility(INVISIBLE);
            }

            @Override
            public void onAnimationRepeat(Animation animation) {

            }
        });

        LayoutInflater.from(getContext()).inflate(R.layout.view_live_answer, this, true);

        decountTitleView = (DecountTitleView) findViewById(R.id.decount_view);
        mQuestionView = (TextView) findViewById(R.id.question);
        mAnswerList = (LinearLayout) findViewById(R.id.answer_list);

        setVisibility(INVISIBLE);

        setKeepScreenOn(true);

        decountTitleView.setDuration(11 * 1000);//11秒的显示时间
        decountTitleView.setOnDecountListener(new DecountTitleView.OnDecountListener() {
            @Override
            public void onDecount(int value) {

            }

            @Override
            public void onDecountEnd() {
                countEnd = true;
                if (onTimeRemainListener != null) {
                    onTimeRemainListener.decountEnd();
                }
            }
        });
    }

    public void show() {
        setVisibility(VISIBLE);
        startAnimation(popInAnim);
    }


    public void hide() {
        startAnimation(popOutAnim);
    }

    public void setQuestion(QuestionInfo question, boolean canAnswer) {
        if (question == null) {
            return;
        }
        countEnd = false;
        mMyAnswer = null;
        bindQuestionToView(question, canAnswer);
        decountTitleView.setQuestionMode(hasLose ? DecountTitleView.TextMode.Lose : DecountTitleView.TextMode.Normal);
        decountTitleView.start();
    }


    private boolean hasLose = false;

    private void bindQuestionToView(QuestionInfo question, boolean canAnswer) {
        if (mCanAnswer) {
            hasLose = false;
        } else {
            hasLose = true;
        }
        mCanAnswer = canAnswer;
        mQuestionInfo = question;
        mQuestionView.setText(question.questionTitle);
        addAllAnswerItems(question.options);
    }

    //    private int count = 10;
    private boolean countEnd = false;

    public void setServivor(boolean survivor) {
        mCanAnswer = survivor;
    }

    private static class DecountTimer extends Handler {

        private WeakReference<LiveAnswerView> liveAnswerViewWeakReference;

        public DecountTimer(LiveAnswerView view) {
            liveAnswerViewWeakReference = new WeakReference<LiveAnswerView>(view);
        }

        @Override
        public void handleMessage(Message msg) {
            super.handleMessage(msg);

            LiveAnswerView liveAnswerView = liveAnswerViewWeakReference.get();
            if (liveAnswerView != null) {
                liveAnswerView.handleMessage(msg);
            }
        }
    }


    private void handleMessage(Message msg) {
        if (WHAT_RESULT_DECOUNT == msg.what) {
            if (onTimeRemainListener != null) {
                onTimeRemainListener.resultEnd();
            }
        }
    }


    int WHAT_RESULT_DECOUNT = 1;

    private void addAllAnswerItems(OptionInfo[] answers) {
        mAnswerList.removeAllViews();

        if (answers == null) {
            return;
        }

        int size = answers.length;
        for (int i = 0; i < size ; i++) {
            OptionInfo ans = answers[i];
            final AnswerItemView itemView = new AnswerItemView(getContext());
            itemView.setId(R.id.custom_id_min + i); //自动化测试用id

            itemView.setAnswer(ans);
            itemView.setOnClickListener(new OnClickListener() {
                @Override
                public void onClick(View v) {
                    if (mMyAnswer == null && !countEnd && !hasLose && mCanAnswer) {
                        itemView.chooseThis();
                        mMyAnswer = itemView.getAnswer();

                        if (onTimeRemainListener != null) {
                            AnswerRequestInfo answerRequestInfo = getMyAnswer();
                            onTimeRemainListener.onChoose(answerRequestInfo);
                        }
                    }
                }
            });

            mAnswerList.addView(itemView, LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT);
        }
    }

    public enum ResultStatus {
        None, Right, Wrong, Lose
    }

    public ResultStatus setResult(QuestionInfo questionReportInfo, boolean canAnswer, int showTimeSec) {

        countEnd = true;

        if (questionReportInfo == null) {
            return ResultStatus.None;
        }

        mCanAnswer = canAnswer;
        mQuestionInfo = questionReportInfo;

        mQuestionView.setText(mQuestionInfo.questionTitle);
        int childCount = mAnswerList.getChildCount();

        if (childCount == 0) {
            //答题过了，才进来。。
            addAllAnswerItems(questionReportInfo.options);
        }

        childCount = mAnswerList.getChildCount();
        if (childCount > 0) {
            for (int i = 0; i < childCount; i++) {
                ((AnswerItemView) mAnswerList.getChildAt(i)).showResult(questionReportInfo);
            }
        }

        decountTimer.sendEmptyMessageDelayed(WHAT_RESULT_DECOUNT, 5 * 1000);//固定5秒

        DecountTitleView.TextMode resultMode;
        if (canAnswer) {
            resultMode = DecountTitleView.TextMode.Right;
        } else {
            if (hasLose) {
                resultMode = DecountTitleView.TextMode.Lose;

            } else {
                resultMode = DecountTitleView.TextMode.Wrong;
            }
        }
        decountTitleView.setResultMode(resultMode);

        ResultStatus resultStatus = ResultStatus.None;
        if (canAnswer) {
            resultStatus = ResultStatus.Right;
        } else {
            if (hasLose) {
                resultStatus = ResultStatus.Lose;
            } else {
                resultStatus = ResultStatus.Wrong;
            }
        }
        return resultStatus;

    }


    public AnswerRequestInfo getMyAnswer() {
        if (mMyAnswer == null || mQuestionInfo == null) {
            return null;
        }

        AnswerRequestInfo answerRequestInfo = new AnswerRequestInfo();
        answerRequestInfo.answerId = mMyAnswer.answerId;
        answerRequestInfo.questionId = mQuestionInfo.questionId;

        return answerRequestInfo;
    }

    public interface OnTimeRemainListener {
        void decountEnd();

        void resultEnd();

        void onChoose(AnswerRequestInfo answerRequestInfo);
    }

    private OnTimeRemainListener onTimeRemainListener;

    public void setOnTimeRemainListener(OnTimeRemainListener l) {
        onTimeRemainListener = l;
    }

}
