package com.aliyun.vodplayer.demo.activity.advance.liveanswer.request;

import android.content.Context;
import android.text.TextUtils;

import com.alivc.player.AliyunErrorCode;
import com.alivc.player.VcPlayerLog;
import com.aliyun.vodplayer.demo.activity.advance.liveanswer.Contants;
import com.aliyun.vodplayer.demo.activity.advance.liveanswer.bean.Result;
import com.aliyun.vodplayer.demo.activity.advance.liveanswer.bean.UserCountResponse;
import com.aliyun.vodplayer.utils.BaseRequest;
import com.aliyun.vodplayer.utils.HttpClientUtil;
import com.google.gson.Gson;

import org.json.JSONException;
import org.json.JSONObject;

/*
 * Copyright (C) 2010-2017 Alibaba Group Holding Limited.
 */
public class GetUserCountRequest extends BaseRequest {


    private static final String TAG = GetUserCountRequest.class.getSimpleName();


    private UserCountParam userCountParam;

    public static class UserCountParam {
        public String liveId;
        public String userId;
    }

    public GetUserCountRequest(Context context, UserCountParam param, BaseRequest.OnRequestListener l) {
        super(context, l);
        userCountParam = param;
    }


    @Override
    public void runInBackground() {

        String url = Contants.ROOM_HOST + "/app/getUserCount";

        String responseStr = null;
        try {
            String data = new Gson().toJson(userCountParam);
            VcPlayerLog.d(TAG, "GetUserCountRequest url = " + url + " , data = " + data);
            responseStr = HttpClientUtil.doPost(url, data);
            VcPlayerLog.d(TAG, "GetUserCountRequest response : " + responseStr);

            if (TextUtils.isEmpty(responseStr)) {

                sendFailResult(AliyunErrorCode.ALIVC_ERR_DATA_ERROR.getCode(),
                        AliyunErrorCode.ALIVC_ERR_DATA_ERROR.getDescription(mContextWeak.get()),
                        "");
                return;
            }

            JSONObject responseJson = new JSONObject(responseStr);
            UserCountResponse userCountResponse = UserCountResponse.getFromJson(responseJson);
            if (userCountResponse == null || userCountResponse.data == null) {
                sendFailResult(AliyunErrorCode.ALIVC_ERR_DATA_ERROR.getCode(),
                        AliyunErrorCode.ALIVC_ERR_DATA_ERROR.getDescription(mContextWeak.get()),
                        "");
                return;
            } else {
                Result result = userCountResponse.result;
                if (result != null) {
                    if (result.code.equalsIgnoreCase("Success")) {
                        sendSuccessResult(userCountResponse.data, "");
                    } else {
                        sendFailResult(AliyunErrorCode.ALIVC_ERR_REQUEST_ERROR.getCode(),
                                result.message, "");
                    }
                } else {
                    sendFailResult(AliyunErrorCode.ALIVC_ERR_DATA_ERROR.getCode(),
                            AliyunErrorCode.ALIVC_ERR_DATA_ERROR.getDescription(mContextWeak.get()),
                            "");
                }
            }

        } catch (JSONException e) {
            VcPlayerLog.e(TAG , "e : " + e.getMessage());

            sendFailResult(AliyunErrorCode.ALIVC_ERR_DATA_ERROR.getCode(),
                    AliyunErrorCode.ALIVC_ERR_DATA_ERROR.getDescription(mContextWeak.get()),
                    "");

        } catch (Exception e) {
            VcPlayerLog.e(TAG , "e : " + e.getMessage());

            sendFailResult(AliyunErrorCode.ALIVC_ERR_NO_NETWORK.getCode(),
                    AliyunErrorCode.ALIVC_ERR_NO_NETWORK.getDescription(mContextWeak.get()),
                    "");
        }

    }

    @Override
    public void stopInner() {

    }
}
